@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: binary-tagged
-version: 0.1.3.1
-id: binary-tagged-0.1.3.1-9446d28c7830037bb28494774c1ef2b9
-key: binar_JdYQX1qlc44Dlr6iwDSLEh
+version: 0.1.4.0
+id: binary-tagged-0.1.4.0-07ba9310509de53d819f2eb756aa7f9b
+key: binar_EMMnfSvcDP7KuMUMDiFq8V
 license: BSD3
 maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
 homepage: https://github.com/phadej/binary-tagged#readme
@@ -16,10 +16,10 @@ exposed: True
 exposed-modules:
     Data.Binary.Tagged
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/binary-tagged-0.1.3.1
-library-dirs: /usr/lib/ghc-7.10.3/site-local/binary-tagged-0.1.3.1
-data-dir: /usr/share/arm-linux-ghc-7.10.3/binary-tagged-0.1.3.1
-hs-libraries: HSbinary-tagged-0.1.3.1-JdYQX1qlc44Dlr6iwDSLEh
+import-dirs: /usr/lib/ghc-7.10.3/site-local/binary-tagged-0.1.4.0
+library-dirs: /usr/lib/ghc-7.10.3/site-local/binary-tagged-0.1.4.0
+data-dir: /usr/share/arm-linux-ghc-7.10.3/binary-tagged-0.1.4.0
+hs-libraries: HSbinary-tagged-0.1.4.0-EMMnfSvcDP7KuMUMDiFq8V
 depends:
     SHA-1.6.4.2-532d5f478144692bd18b7bfd3a13e191
     aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
@@ -31,6 +31,7 @@ depends:
     generics-sop-0.2.1.0-7239eda8d6e847745310ee1c6aedf3ba
     hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
     scientific-0.3.4.6-7ee193f22b0f4a7e2e484deeaee5cd03
+    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
     tagged-0.8.3-aa128de4449752177a05765fb0ce3959
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
